@@ -24,6 +24,7 @@ class TimecodeTester(unittest.TestCase):
     def test_instance_creation(self):
         """test instance creation, none of these should raise any error
         """
+        Timecode('23.976', '00:00:00:00')
         Timecode('23.98', '00:00:00:00')
         Timecode('24', '00:00:00:00')
         Timecode('25', '00:00:00:00')
@@ -35,6 +36,7 @@ class TimecodeTester(unittest.TestCase):
         Timecode('ms', '03:36:09.230')
         Timecode('24', start_timecode=None, frames=12000)
 
+        Timecode('23.976')
         Timecode('23.98')
         Timecode('24')
         Timecode('25')
@@ -45,6 +47,7 @@ class TimecodeTester(unittest.TestCase):
         Timecode('60')
         Timecode('ms')
 
+        Timecode('23.976', 421729315)
         Timecode('23.98', 421729315)
         Timecode('24', 421729315)
         Timecode('25', 421729315)
@@ -70,6 +73,7 @@ class TimecodeTester(unittest.TestCase):
         Timecode((60000, 1001), '00:00:00;00')
 
         Timecode(24, frames=12000)
+        Timecode(23.976, '00:00:00:00')
         Timecode(23.98, '00:00:00:00')
         Timecode(24, '00:00:00:00')
         Timecode(25, '00:00:00:00')
@@ -81,6 +85,7 @@ class TimecodeTester(unittest.TestCase):
         Timecode(1000, '03:36:09.230')
         Timecode(24, start_timecode=None, frames=12000)
 
+        Timecode(23.976)
         Timecode(23.98)
         Timecode(24)
         Timecode(25)
@@ -92,6 +97,12 @@ class TimecodeTester(unittest.TestCase):
         Timecode(1000)
         Timecode(24, frames=12000)
 
+    def test_2398_vs_23976(self):
+        timeobj1 = Timecode('23.98', '04:01:45:23')
+        timeobj2 = Timecode('23.976', '04:01:45:23')
+        self.assertEqual(timeobj1.frames, timeobj2.frames)
+        self.assertEqual(repr(timeobj1), repr(timeobj2))
+
     def test_repr_overload(self):
         timeobj = Timecode('24', '01:00:00:00')
         self.assertEqual('01:00:00:00', timeobj.__repr__())
@@ -102,6 +113,9 @@ class TimecodeTester(unittest.TestCase):
         timeobj = Timecode('29.97', '00:09:00;00')
         self.assertEqual('00:08:59;28', timeobj.__repr__())
 
+        timeobj = Timecode('29.97', '00:09:00:00', force_non_drop_frame=True)
+        self.assertEqual('00:08:59:14', timeobj.__repr__())
+
         timeobj = Timecode('30', '00:10:00:00')
         self.assertEqual('00:10:00:00', timeobj.__repr__())
 
@@ -130,12 +144,24 @@ class TimecodeTester(unittest.TestCase):
         self.assertEqual('00:00:00;00', tc.__str__())
         self.assertEqual(1, tc.frames)
 
+        tc = Timecode('29.97', force_non_drop_frame=True)
+        self.assertEqual('00:00:00:00', tc.__str__())
+        self.assertEqual(1, tc.frames)
+
+        tc = Timecode('29.97', force_non_drop_frame=True)
+
         tc = Timecode('29.97', '00:00:00;01')
         self.assertEqual(2, tc.frames)
 
+        tc = Timecode('29.97', '00:00:00:01', force_non_drop_frame=True)
+        self.assertEqual(2, tc.frames)
+
         tc = Timecode('29.97', '03:36:09;23')
         self.assertEqual(388704, tc.frames)
 
+        tc = Timecode('29.97', '03:36:09:23', force_non_drop_frame=True)
+        self.assertEqual(388705, tc.frames)
+
         tc = Timecode('29.97', '03:36:09;23')
         self.assertEqual(388704, tc.frames)
 
@@ -175,6 +201,9 @@ class TimecodeTester(unittest.TestCase):
         tc = Timecode('29.97', frames=2589409)
         self.assertEqual('00:00:00;00', tc.__str__())
 
+        tc = Timecode('29.97', frames=2589409, force_non_drop_frame=True)
+        self.assertEqual('00:00:00:00', tc.__str__())
+
         tc = Timecode('59.94', frames=5178816)
         self.assertEqual('23:59:59;59', tc.__str__())
 
@@ -305,6 +334,10 @@ class TimecodeTester(unittest.TestCase):
         tc = Timecode('29.97', '23:59:59;29')
         self.assertEqual(2589408, tc.frames)
 
+    def test_force_drop_frame_to_false(self):
+        tc = Timecode('29.97', '01:00:00:00', force_non_drop_frame=True)
+        self.assertEqual('00:59:56:12', tc.__repr__())
+
     def test_drop_frame(self):
         tc = Timecode('29.97', '13:36:59;29')
         timecode = tc.next()
@@ -365,6 +398,16 @@ class TimecodeTester(unittest.TestCase):
         assert t == "03:36:11;23"
         assert tc.frames == 388764
 
+        # tc = Timecode('29.97', '03:36:09;23', force_drop_frame_to=False)
+        # assert tc == '03:36:09;23'
+
+        # for x in range(60):
+        #     t = tc.next()
+        #     self.assertTrue(t)
+
+        # assert t == ''
+        # assert tc.frames == 388764
+
         tc = Timecode('29.97', '03:36:09;23')
         for x in range(60):
             t = tc.next()
@@ -978,22 +1021,58 @@ class TimecodeTester(unittest.TestCase):
         tc1 = Timecode(24, '00:00:00:00')
         tc2 = Timecode(24, '00:00:00:00')
         tc3 = Timecode(24, '00:00:00:01')
+        tc4 = Timecode(24, '00:00:01.100')
+        tc5 = Timecode(24, '00:00:01.200')
 
         self.assertTrue(tc1 == tc2)
         self.assertTrue(tc1 >= tc2)
         self.assertTrue(tc3 >= tc2)
         self.assertFalse(tc2 >= tc3)
+        self.assertTrue(tc4 <= tc5)
+
+    def test_gt_overload(self):
+        tc1 = Timecode(24, '00:00:00:00')
+        tc2 = Timecode(24, '00:00:00:00')
+        tc3 = Timecode(24, '00:00:00:01')
+        tc4 = Timecode(24, '00:00:01.100')
+        tc5 = Timecode(24, '00:00:01.200')
+
+        self.assertFalse(tc1 > tc2)
+        self.assertFalse(tc2 > tc2)
+        self.assertTrue(tc3 > tc2)
+        self.assertTrue(tc5 > tc4)
 
     def test_le_overload(self):
         tc1 = Timecode(24, '00:00:00:00')
         tc2 = Timecode(24, '00:00:00:00')
         tc3 = Timecode(24, '00:00:00:01')
+        tc4 = Timecode(24, '00:00:01.100')
+        tc5 = Timecode(24, '00:00:01.200')
 
         self.assertTrue(tc1 == tc2)
         self.assertTrue(tc1 <= tc2)
         self.assertTrue(tc2 <= tc3)
         self.assertFalse(tc2 >= tc3)
+        self.assertTrue(tc5 >= tc4)
+        self.assertTrue(tc5 > tc4)
 
+    def test_gt_overload(self):
+        tc1 = Timecode(24, '00:00:00:00')
+        tc2 = Timecode(24, '00:00:00:00')
+        tc3 = Timecode(24, '00:00:00:01')
+        tc4 = Timecode(24, '00:00:01.100')
+        tc5 = Timecode(24, '00:00:01.200')
+
+        self.assertFalse(tc1 < tc2)
+        self.assertFalse(tc2 < tc2)
+        self.assertTrue(tc2 < tc3)
+        self.assertTrue(tc4 < tc5)
+
+    def test_parse_timecode_with_int(self):
+        """tests parse_timecode method with int input
+        """
+        result = Timecode.parse_timecode(16663)
+        self.assertTrue(result == (0, 0, 41, 17))  # issue #16
 
     # def test_exceptions(self):
     #     """test exceptions
@@ -1100,3 +1179,6 @@ class TimecodeTester(unittest.TestCase):
     #         "Type str not supported for arithmetic.",
     #         cm.exception.__str__()
     #     )
+
+if __name__ == '__main__':
+    unittest.main()
